#!/usr/bin/env python3
# -*- coding: utf-8 -*-

buffer = []
edgeSequence = []

class Edge:

    edgeCount = 0
    edgeIndex = []
    edgeColor = []
    
    def solveEdge(self, sides, edgePriority):
        
        edgeGoal = (sides['U'][1]=='U' and sides['U'][3]=='U' and sides['U'][5]=='U' and sides['U'][7]=='U'
                and sides['F'][1]=='F' and sides['F'][3]=='F' and sides['F'][5]=='F' and sides['F'][7]=='F'
                and sides['R'][1]=='R' and sides['R'][3]=='R' and sides['R'][5]=='R' and sides['R'][7]=='R'
                and sides['D'][1]=='D' and sides['D'][3]=='D' and sides['D'][5]=='D' and sides['D'][7]=='D'
                and sides['B'][1]=='B' and sides['B'][3]=='B' and sides['B'][5]=='B' and sides['B'][7]=='B'
                and sides['L'][1]=='L' and sides['L'][3]=='L' and sides['L'][5]=='L' and sides['L'][7]=='L')

        if (edgeGoal):
            print('Edges are already solved!')
            
        else:
            
            if (sides['U'][5]=='U' and sides['R'][1]=='R') or (sides['U'][5]=='R' and sides['R'][1]=='U'):
                if (sides['U'][5]=='U' and sides['R'][1]=='R'):
                    self.edgeColor.append(['U','R'])
                else:
                    self.edgeColor.append(['R','U'])
                buffer = self.edgeBufferChange(sides,edgePriority)
                self.edgeCount = self.edgeCount + 1
                
            if not (sides['U'][5]=='U' and sides['R'][1]=='R') or (sides['U'][5]=='R' and sides['R'][1]=='U'):
                buffer = [sides['U'][5], sides['R'][1]]
                
                while(1):
                    edgeGoalbuffer =(sides['U'][1]=='U' and sides['U'][3]=='U' and sides['U'][7]=='U'
                                and sides['F'][1]=='F' and sides['F'][3]=='F' and sides['F'][5]=='F' and sides['F'][7]=='F'
                                and sides['R'][3]=='R' and sides['R'][5]=='R' and sides['R'][7]=='R'
                                and sides['D'][1]=='D' and sides['D'][3]=='D' and sides['D'][5]=='D' and sides['D'][7]=='D'
                                and sides['B'][1]=='B' and sides['B'][3]=='B' and sides['B'][5]=='B' and sides['B'][7]=='B'
                                and sides['L'][1]=='L' and sides['L'][3]=='L' and sides['L'][5]=='L' and sides['L'][7]=='L')
                    
                    if (edgeGoalbuffer):
                        sides['U'][5] = 'U'
                        sides['R'][1] = 'R'
                        
                        if not(self.edgeCount%2==0):
                            sidesCopy = sides.copy()
                            parity = [sidesCopy['U'][8], sidesCopy['R'][0], sidesCopy['F'][2],
                                    sidesCopy['U'][2], sidesCopy['B'][0], sidesCopy['R'][2]]
                            sides['U'][2] = parity[0]
                            sides['B'][0] = parity[1]
                            sides['R'][2] = parity[2]
                            
                            sides['U'][8] = parity[3]
                            sides['R'][0] = parity[4]
                            sides['F'][2] = parity[5]
                        
                        #print('Edges are solved!')
                        #print(sides)
                        
                        break
                    
                        
                    face = [buffer[0], buffer[1]]
                    
                    prevBuffer = buffer
                    if (sides['U'][5]=='U' and sides['R'][1]=='R') or (sides['U'][5]=='R' and sides['R'][1]=='U'):
                        
                        self.edgeColor.append(['R','U'])
                        buffer = self.edgeBufferChange(sides,edgePriority)
                        
                    else:
                        edgeSequence.append(buffer)
                        self.edgeColor.append(buffer)
                        
                        index = self.getEdgeIndex(buffer)
                        self.edgeIndex.append([buffer[0],index[0],buffer[1],index[1]])
                        
                        buffer = [sides[buffer[0]][index[0]],sides[buffer[1]][index[1]]] #update buffer
                        
                        sides[prevBuffer[0]][index[0]] = prevBuffer[0]
                        sides[prevBuffer[1]][index[1]] = prevBuffer[1]
                        
                        sides['U'][5] = buffer[0]
                        sides['R'][1] = buffer[1]
                        
                    
                    self.edgeCount = self.edgeCount + 1
                    
                    
        return sides
        
    
    def edgeBufferChange (self,sides,edgePriority):
        sidesCopy = sides.copy()
        a1 = ''
        a2 = 0
        b1 = ''
        b2 = 0
        
        if not (sides[edgePriority[0][0]][edgePriority[0][1]]=='U'
            and sides[edgePriority[0][2]][edgePriority[0][3]]=='B'):
            a1 = 'U'
            a2 = 1
            b1 = 'B'
            b2 = 1
            
            buffer = ['U','B']
            edgeSequence.append(buffer)
            
        elif not (sides[edgePriority[1][0]][edgePriority[1][1]]=='U'
            and sides[edgePriority[1][2]][edgePriority[1][3]]=='L'):
            a1 = 'U'
            a2 = 3
            b1 = 'L'
            b2 = 1
            
            buffer = ['U','L']
            edgeSequence.append(buffer)
        
        elif not (sides[edgePriority[2][0]][edgePriority[2][1]]=='U' 
            and sides[edgePriority[2][2]][edgePriority[2][3]]=='F'):
            a1 = 'U'
            a2 = 7
            b1 = 'F'
            b2 = 1
            
            buffer = ['U','F']
            edgeSequence.append(buffer)
            
        elif not (sides[edgePriority[3][0]][edgePriority[3][1]]=='B' 
            and sides[edgePriority[3][2]][edgePriority[3][3]]=='L'):
            a1 = 'B'
            a2 = 5
            b1 = 'L'
            b2 = 3
            
            buffer = ['B','L']
            edgeSequence.append(buffer)
            
        elif not (sides[edgePriority[4][0]][edgePriority[4][1]]=='L' 
            and sides[edgePriority[4][2]][edgePriority[4][3]]=='F'):
            a1 = 'L'
            a2 = 5
            b1 = 'F'
            b2 = 3
            
            buffer = ['L','F']
            edgeSequence.append(buffer)
        
        elif not (sides[edgePriority[5][0]][edgePriority[5][1]]=='F' 
            and sides[edgePriority[5][2]][edgePriority[5][3]]=='R'):
            a1 = 'F'
            a2 = 5
            b1 = 'R'
            b2 = 3
            
            buffer = ['F','R']
            edgeSequence.append(buffer)
            
        elif not (sides[edgePriority[6][0]][edgePriority[6][1]]=='R' 
            and sides[edgePriority[6][2]][edgePriority[6][3]]=='B'):
            a1 = 'R'
            a2 = 5
            b1 = 'B'
            b2 = 3
            
            buffer = ['R','B']
            edgeSequence.append(buffer)
        
        elif not (sides[edgePriority[7][0]][edgePriority[7][1]]=='D' 
            and sides[edgePriority[7][2]][edgePriority[7][3]]=='F'):
            a1 = 'D'
            a2 = 1
            b1 = 'F'
            b2 = 7
            
            buffer = ['D','F']
            edgeSequence.append(buffer)
        
        elif not (sides[edgePriority[8][0]][edgePriority[8][1]]=='D' 
            and sides[edgePriority[8][2]][edgePriority[8][3]]=='L'):
            a1 = 'D'
            a2 = 3
            b1 = 'L'
            b2 = 7
            
            buffer = ['D','L']
            edgeSequence.append(buffer)
        
        elif not (sides[edgePriority[9][0]][edgePriority[9][1]]=='D' 
            and sides[edgePriority[9][2]][edgePriority[9][3]]=='R'):
            a1 = 'D'
            a2 = 5
            b1 = 'R'
            b2 = 7
            
            buffer = ['D','R']
            edgeSequence.append(buffer)
            
        elif not (sides[edgePriority[10][0]][edgePriority[10][1]]=='D' 
            and sides[edgePriority[10][2]][edgePriority[10][3]]=='B'):
            a1 = 'D'
            a2 = 7
            b1 = 'B'
            b2 = 7
            
            buffer = ['D','B']
            edgeSequence.append(buffer)
        
        
        index = self.getEdgeIndex(buffer)
        self.edgeIndex.append([buffer[0],index[0],buffer[1],index[1]])
        
        swap = [sidesCopy['R'][1], sidesCopy['U'][5], sidesCopy[a1][a2], sidesCopy[b1][b2]]
        
        if (sides['U'][5]=='U' and sides['R'][1]=='R'):
            buffer = [sides[a1][a2],sides[b1][b2]]
            
            sides[b1][b2] = swap[0]
            sides[a1][a2] = swap[1]
            
            sides['U'][5] = swap[2]
            sides['R'][1] = swap[3]
            
        else:
            buffer = [sides[a1][a2],sides[b1][b2]]
            
            sides[b1][b2] = swap[0]
            sides[a1][a2] = swap[1]
            
            sides['U'][5] = swap[2]
            sides['R'][1] = swap[3]
            
        return buffer
    

    def getEdgeIndex(self,buffer):
        if buffer[0]=='U':
            if buffer[1]=='R':
                index = [5,1]
            elif buffer[1]=='F':
                index = [7,1]
            elif buffer[1]=='B':
                index = [1,1]
            elif buffer[1]=='L':
                index = [3,1]
        elif buffer[0]=='F':
            if buffer[1]=='U':
                index = [1,7]
            elif buffer[1]=='R':
                index = [5,3]
            elif buffer[1]=='D':
                index = [7,1]
            elif buffer[1]=='L':
                index = [3,5]
        elif buffer[0]=='R':
            if buffer[1]=='U':
                index = [1,5]
            elif buffer[1]=='F':
                index = [3,5]
            elif buffer[1]=='D':
                index = [7,5]
            elif buffer[1]=='B':
                index = [5,3]
        elif buffer[0]=='D':
            if buffer[1]=='F':
                index = [1,7]
            elif buffer[1]=='R':
                index = [5,7]
            elif buffer[1]=='B':
                index = [7,7]
            elif buffer[1]=='L':
                index = [3,7]
        elif buffer[0]=='B':
            if buffer[1]=='U':
                index = [1,1]
            elif buffer[1]=='R':
                index = [3,5]
            elif buffer[1]=='D':
                index = [7,7]
            elif buffer[1]=='L':
                index = [5,3]
        elif buffer[0]=='L':
            if buffer[1]=='U':
                index = [1,3]
            elif buffer[1]=='F':
                index = [5,3]
            elif buffer[1]=='D':
                index = [7,3]
            elif buffer[1]=='B':
                index = [3,5]
        return index
    
    
    def getEdgeSequence(self):
        return edgeSequence
    
    
    
    
cubeEdges = Edge()


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from .edge import *
from .corner import *

solvedEdges = []
solvedCorners = []

cube = {}
edgeSequence = []
cornerSequence = []

edgePriority = {0:['U',1,'B',1],
                1:['U',3,'L',1],
                2:['U',7,'F',1],
                3:['B',5,'L',3],
                4:['L',5,'F',3],
                5:['F',5,'R',3],
                6:['R',5,'B',3],
                7:['D',1,'F',7],
                8:['D',3,'L',7],
                9:['D',5,'R',7],
                10:['D',7,'B',7]}
                
cornerPriority = {0:['U',2,'R',2,'B',0],
                    1:['U',6,'L',2,'F',0],
                    2:['U',8,'F',2,'R',0],
                    3:['D',0,'F',6,'L',8],
                    4:['D',2,'R',6,'F',8],
                    5:['D',6,'L',6,'B',8],
                    6:['D',8,'B',6,'R',8]}


def setCube(sides):
    global cube
    cube = sides
    
    
def displayCube():
    return cube
   
    
def updateEdgePriority(inputEdgePriority):
    global edgePriority
    for x in range(11):
        if x in inputEdgePriority.keys(): 
            edgePriority[x] = inputEdgePriority.get(x)
   
   
def displayEdgePriority():
    return edgePriority
    
    
def updateCornerPriority(inputCornerPriority):
    global cornerPriority
    for x in range(7):
        if x in inputCornerPriority.keys(): 
            cornerPriority[x] = inputCornerPriority.get(x)
    
    
def displayCornerPriority():
    return cornerPriority
    

def solveEdges():
    global cube
    global edgeSequence
    cube = cubeEdges.solveEdge(cube,edgePriority)
    edgeSequence = cubeEdges.getEdgeSequence()
    if (len(edgeSequence)>0):
        return edgeSequence
    else:
        return None


def solveCorners():
    global cube
    global cornerSequence
    cube = cubeCorners.solveCorner(cube,cornerPriority)
    cornerSequence = cubeCorners.getCornerSequence()
    if (len(cornerSequence)>0):
        return cornerSequence
    else:
        return None
 

def indexEdgeSequence():
    if (len(edgeSequence)>0):
        return cubeEdges.edgeIndex
    else:
        return None
        

def indexCornerSequence():
    if (len(cornerSequence)>0):
        return cubeCorners.cornerIndex
    else:
        return None
        

def currentEdgeBuffer():
    if (len(edgeSequence)>0):
        return cubeEdges.edgeColor
    else:
        return None


def currentCornerBuffer():
    if (len(cornerSequence)>0):
        return cubeCorners.cornerColor
    else:
        return None
        
        
def parityCheck():
    if (len(edgeSequence)>0 or len(cornerSequence)>0):
        if not(len(edgeSequence)%2==0) or not (len(cornerSequence)%2==0):
            parity = 1
            return parity
        else:
            parity = 0
            return parity
    else:
        return None
        

def parityAlgorithm():
    if not(len(cornerSequence)%2==0) or not (len(edgeSequence)%2==0):
        sidesCopy = cube.copy()
        edgeParity = [sidesCopy['U'][8], sidesCopy['R'][0], sidesCopy['F'][2],
                sidesCopy['U'][2], sidesCopy['B'][0], sidesCopy['R'][2]]
        cube['U'][2] = edgeParity[0]
        cube['B'][0] = edgeParity[1]
        cube['R'][2] = edgeParity[2] 
        
        cube['U'][8] = edgeParity[3]
        cube['R'][0] = edgeParity[4]
        cube['F'][2] = edgeParity[5]
        
        cornerParity = [sidesCopy['U'][3], sidesCopy['L'][1], sidesCopy['U'][1], sidesCopy['B'][1]]
        cube['U'][1] = cornerParity[0]
        cube['B'][1] = cornerParity[1]
        
        cube['U'][3] = cornerParity[2]
        cube['L'][1] = cornerParity[3]
    
    
def getSolvedEdges():
    value = [1,3,5,7]
    for x in range(4):
        if (cube['U'][value[x]]=='U'):
            if (x==0):
                if (cube['B'][1]=='B'):
                    solvedEdges.append(['U',1,'B',1])
            elif (x==1):
                if (cube['L'][1]=='L'):
                    solvedEdges.append(['U',3,'L',1])
            elif (x==2):
                if (cube['R'][1]=='R'):
                    solvedEdges.append(['U',5,'R',1])
            elif (x==3):
                if (cube['F'][1]=='F'):
                    solvedEdges.append(['U',7,'F',1])
        if (cube['F'][value[x]]=='F'):
            if (x==1):
                if (cube['L'][5]=='L'):
                    solvedEdges.append(['F',3,'L',5])
            elif (x==2):
                if (cube['R'][3]=='R'):
                    solvedEdges.append(['F',5,'R',3])
        if (cube['D'][value[x]]=='D'):
            if (x==0):
                if (cube['F'][7]=='F'):
                    solvedEdges.append(['D',1,'F',7])
            elif (x==1):
                if (cube['L'][7]=='L'):
                    solvedEdges.append(['D',3,'L',7])
            elif (x==2):
                if (cube['R'][7]=='R'):
                    solvedEdges.append(['D',5,'R',7])
            elif (x==3):
                if (cube['B'][7]=='B'):
                    solvedEdges.append(['D',7,'B',7])
        if (cube['B'][value[x]]=='B'):
            if (x==1):
                if (cube['R'][5]=='R'):
                    solvedEdges.append(['B',3,'R',5])
            elif (x==2):
                if (cube['L'][3]=='L'):
                    solvedEdges.append(['B',5,'L',3])
                    
    if (len(solvedEdges)>0):                 
        return solvedEdges                
    else:
        return None


def getSolvedCorners():
    value = [0,2,6,8]
    for x in range(4):
        if (cube['U'][value[x]]=='U'):
            if (x==0):
                if cube['L'][0]=='L':
                    if cube['B'][2]=='B':
                        solvedCorners.append(['U',0,'L',0,'B',2])
            elif (x==1):
                if cube['B'][0]=='B':
                    if cube['R'][2]=='R':
                        solvedCorners.append(['U',2,'B',0,'R',2])
            elif (x==2):
                if cube['L'][2]=='L':
                    if cube['F'][0]=='F':
                        solvedCorners.append(['U',6,'L',2,'F',0]) 
            elif (x==3):
                if cube['R'][0]=='R':
                    if cube['F'][2]=='F':
                        solvedCorners.append(['U',8,'R',0,'F',2]) 
        elif (cube['D'][value[x]]=='D'):
            if (x==0):
                if cube['L'][8]=='L':
                    if cube['F'][6]=='F':
                        solvedCorners.append(['D',0,'L',8,'F',6])
            elif (x==1):
                if cube['F'][8]=='F':
                    if cube['R'][6]=='R':
                        solvedCorners.append(['D',2,'F',8,'R',6])
            elif (x==2):
                if cube['L'][6]=='L':
                    if cube['B'][8]=='B':
                        solvedCorners.append(['D',6,'L',6,'B',8])
            elif (x==3):
                if cube['B'][6]=='B':
                    if cube['R'][8]=='R':
                        solvedCorners.append(['D',8,'B',6,'R',8])
                        
    if (len(solvedCorners)>0):                 
        return solvedCorners                
    else:
        return None
            
            



from setuptools import setup

def readme():
    with open('README.md') as f:
        README = f.read()
    return README


setup(
    name="RubiksBlindfolded",
    version="1.0.3",
    description="A Python package of solving Rubik's Cube in Blindfolded technique.",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/mn-banjar/RubiksBlindfolded",
    author="Moneera Banjar",
    author_email="mn.banjar@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python" ,
    ],
    packages=["RubiksBlindfolded"],
    include_package_data=True,
    
)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

cornerBuffer = []
cornerSequence = []

class Corner:

    cornerCount = 0
    cornerIndex = []
    cornerColor = []
    
    def solveCorner(self,sides,cornerPriority):
        
        cornerGoal = (sides['U'][0]=='U' and sides['U'][2]=='U' and sides['U'][6]=='U' and sides['U'][8]=='U'
                and sides['F'][0]=='F' and sides['F'][2]=='F' and sides['F'][6]=='F' and sides['F'][8]=='F'
                and sides['R'][0]=='R' and sides['R'][2]=='R' and sides['R'][6]=='R' and sides['R'][8]=='R'
                and sides['D'][0]=='D' and sides['D'][2]=='D' and sides['D'][6]=='D' and sides['D'][8]=='D'
                and sides['B'][0]=='B' and sides['B'][2]=='B' and sides['B'][6]=='B' and sides['B'][8]=='B'
                and sides['L'][0]=='L' and sides['L'][2]=='L' and sides['L'][6]=='L' and sides['L'][8]=='L')

        if (cornerGoal):
            print('Corners are already solved!')
            
        else:
            
            if ((sides['L'][0]=='L' and sides['U'][0]=='U' and sides['B'][2]=='B') or 
                (sides['L'][0]=='U' and sides['U'][0]=='B' and sides['B'][2]=='L') or
                (sides['L'][0]=='B' and sides['U'][0]=='L' and sides['B'][2]=='U')):
                cornerBuffer = self.cornerBufferChange(sides,cornerPriority)
                self.cornerCount = self.cornerCount + 1
                
            if not ((sides['L'][0]=='L' and sides['U'][0]=='U' and sides['B'][2]=='B') or 
                (sides['L'][0]=='U' and sides['U'][0]=='B' and sides['B'][2]=='L') or
                (sides['L'][0]=='B' and sides['U'][0]=='L' and sides['B'][2]=='U')):
                cornerBuffer = [sides['L'][0], sides['U'][0], sides['B'][2]]
                
                
                while(1):
                    cornerGoalbuffer = (sides['U'][2]=='U' and sides['U'][6]=='U' and sides['U'][8]=='U'
                                    and sides['F'][0]=='F' and sides['F'][2]=='F' and sides['F'][6]=='F' and sides['F'][8]=='F'
                                    and sides['R'][0]=='R' and sides['R'][2]=='R' and sides['R'][6]=='R' and sides['R'][8]=='R'
                                    and sides['D'][0]=='D' and sides['D'][2]=='D' and sides['D'][6]=='D' and sides['D'][8]=='D'
                                    and sides['B'][0]=='B' and sides['B'][6]=='B' and sides['B'][8]=='B'
                                    and sides['L'][2]=='L' and sides['L'][6]=='L' and sides['L'][8]=='L')
                    
                    if (cornerGoalbuffer):
                        sides['L'][0] = 'L'
                        sides['U'][0] = 'U'
                        sides['B'][2] = 'B'
                        
                        if not(self.cornerCount%2==0):
                            sidesCopy = sides.copy()
                            parity = [sidesCopy['U'][3], sidesCopy['L'][1], sidesCopy['U'][1], sidesCopy['B'][1]]
                            sides['U'][1] = parity[0]
                            sides['B'][1] = parity[1]
                            
                            sides['U'][3] = parity[2]
                            sides['L'][1] = parity[3]
                        
                        #print('Corners are solved!')
                        #print(sides)
                        
                        break
                    
                        
                    face = [cornerBuffer[0], cornerBuffer[1], cornerBuffer[2]]
                    
                    prevBuffer = cornerBuffer
                    if ((sides['L'][0]=='L' and sides['U'][0]=='U' and sides['B'][2]=='B') or 
                        (sides['L'][0]=='U' and sides['U'][0]=='B' and sides['B'][2]=='L') or
                        (sides['L'][0]=='B' and sides['U'][0]=='L' and sides['B'][2]=='U')):
                        cornerBuffer = self.cornerBufferChange(sides,cornerPriority)
                        
                    else:
                        cornerSequence.append(cornerBuffer)
                        self.cornerColor.append(cornerBuffer)
                        
                        index = self.getCornerIndex(cornerBuffer)
                        self.cornerIndex.append([cornerBuffer[0],index[0],cornerBuffer[1],index[1],cornerBuffer[2],index[2]])
                        

                        cornerBuffer = [sides[cornerBuffer[0]][index[0]],sides[cornerBuffer[1]][index[1]],sides[cornerBuffer[2]][index[2]]] #update buffer
                        
                        sides[prevBuffer[0]][index[0]] = prevBuffer[0]
                        sides[prevBuffer[1]][index[1]] = prevBuffer[1]
                        sides[prevBuffer[2]][index[2]] = prevBuffer[2]
                        
                        sides['L'][0] = cornerBuffer[0]
                        sides['U'][0] = cornerBuffer[1]
                        sides['B'][2] = cornerBuffer[2]
                        
                    self.cornerCount = self.cornerCount + 1
                    
        
        return sides
    
    
    def cornerBufferChange(self,sides,cornerPriority):
        sidesCopy = sides.copy()
        a1 = ''
        a2 = 0
        b1 = ''
        b2 = 0
        c1 = ''
        c2 = 0
        
        if not (sides[cornerPriority[0][0]][cornerPriority[0][1]]=='U' 
            and sides[cornerPriority[0][2]][cornerPriority[0][3]]=='R' 
            and sides[cornerPriority[0][4]][cornerPriority[0][5]]=='B'):
            a1 = 'U'
            a2 = 2
            b1 = 'R'
            b2 = 2
            c1 = 'B'
            c2 = 0
            
            cornerBuffer = ['U','R','B']
            cornerSequence.append(cornerBuffer)
            
        elif not (sides[cornerPriority[1][0]][cornerPriority[1][1]]=='U' 
            and sides[cornerPriority[1][2]][cornerPriority[1][3]]=='L' 
            and sides[cornerPriority[1][4]][cornerPriority[1][5]]=='F'):
            a1 = 'U'
            a2 = 6
            b1 = 'L'
            b2 = 2
            c1 = 'F'
            c2 = 0
            
            cornerBuffer = ['U','L','F']
            cornerSequence.append(cornerBuffer)
        
        elif not (sides[cornerPriority[2][0]][cornerPriority[2][1]]=='U' 
            and sides[cornerPriority[2][2]][cornerPriority[2][3]]=='F' 
            and sides[cornerPriority[2][4]][cornerPriority[2][5]]=='R'):
            a1 = 'U'
            a2 = 8
            b1 = 'F'
            b2 = 2
            c1 = 'R'
            c2 = 0
            
            cornerBuffer = ['U','F','R']
            cornerSequence.append(cornerBuffer)
            
        elif not (sides[cornerPriority[3][0]][cornerPriority[3][1]]=='D' 
            and sides[cornerPriority[3][2]][cornerPriority[3][3]]=='F' 
            and sides[cornerPriority[3][4]][cornerPriority[3][5]]=='L'):
            a1 = 'D'
            a2 = 0
            b1 = 'F'
            b2 = 6
            c1 = 'L'
            c2 = 8
            
            cornerBuffer = ['D','F','L']
            cornerSequence.append(cornerBuffer)
            
        elif not (sides[cornerPriority[4][0]][cornerPriority[4][1]]=='D' 
            and sides[cornerPriority[4][2]][cornerPriority[4][3]]=='R' 
            and sides[cornerPriority[4][4]][cornerPriority[4][5]]=='F'):
            a1 = 'D'
            a2 = 2
            b1 = 'R'
            b2 = 6
            c1 = 'F'
            c2 = 8
            
            cornerBuffer = ['D','R','F']
            cornerSequence.append(cornerBuffer)
        
        elif not (sides[cornerPriority[5][0]][cornerPriority[5][1]]=='D' 
            and sides[cornerPriority[5][2]][cornerPriority[5][3]]=='L' 
            and sides[cornerPriority[5][4]][cornerPriority[5][5]]=='B'):
            a1 = 'D'
            a2 = 6
            b1 = 'L'
            b2 = 6
            c1 = 'B'
            c2 = 8
            
            cornerBuffer = ['D','L','B']
            cornerSequence.append(cornerBuffer)
            
        elif not (sides[cornerPriority[6][0]][cornerPriority[6][1]]=='D' 
            and sides[cornerPriority[6][2]][cornerPriority[6][3]]=='B' 
            and sides[cornerPriority[6][4]][cornerPriority[6][5]]=='R'):
            a1 = 'D'
            a2 = 8
            b1 = 'B'
            b2 = 6
            c1 = 'R'
            c2 = 8
            
            cornerBuffer = ['D','B','R']
            cornerSequence.append(cornerBuffer)
        
        
        index = self.getCornerIndex(cornerBuffer)
        self.cornerIndex.append([cornerBuffer[0],index[0],cornerBuffer[1],index[1],cornerBuffer[2],index[2]])
        
        swap = [sidesCopy['L'][0], sidesCopy['U'][0], sidesCopy['B'][2],
                sidesCopy[a1][a2], sidesCopy[b1][b2], sidesCopy[c1][c2]]
        
        cornerBuffer = [sides[a1][a2],sides[b1][b2],sides[c1][c2]]
        
        
        if (sides['L'][0]=='L' and sides['U'][0]=='U' and sides['B'][2]=='B'):
            self.cornerColor.append(['L','U','B'])
            
        elif (sides['L'][0]=='U' and sides['U'][0]=='B' and sides['B'][2]=='L'):
            self.cornerColor.append(['U','B','L'])
            
        elif (sides['L'][0]=='B' and sides['U'][0]=='L' and sides['B'][2]=='U'):
            self.cornerColor.append(['B','L','U'])
        
        sides[a1][a2] = swap[0]
        sides[b1][b2] = swap[1]
        sides[c1][c2] = swap[2]
        
        sides['L'][0] = swap[3]
        sides['U'][0] = swap[4]
        sides['B'][2] = swap[5]
        
            
        return cornerBuffer
        
    
    def getCornerIndex(self,cornerBuffer):
        if cornerBuffer[0]=='U':
            if cornerBuffer[1]=='R':
                if cornerBuffer[2]=='F':
                    index = [8,0,2]
                elif cornerBuffer[2]=='B':
                    index = [2,2,0]
            elif cornerBuffer[1]=='F':
                if cornerBuffer[2]=='R':
                    index = [8,2,0]
                elif cornerBuffer[2]=='L':
                    index = [6,0,2]
            elif cornerBuffer[1]=='B':
                if cornerBuffer[2]=='R':
                    index = [2,0,2]
                elif cornerBuffer[2]=='L':
                    index = [0,2,0]
            elif cornerBuffer[1]=='L':
                if cornerBuffer[2]=='F':
                    index = [6,2,0]
                elif cornerBuffer[2]=='B':
                    index = [0,0,2]
        elif cornerBuffer[0]=='F':
            if cornerBuffer[1]=='U':
                if cornerBuffer[2]=='R':
                    index = [2,8,0]
                elif cornerBuffer[2]=='L':
                    index = [0,6,2]
            elif cornerBuffer[1]=='R':
                if cornerBuffer[2]=='U':
                    index = [2,0,8]
                elif cornerBuffer[2]=='D':
                    index = [8,6,2]
            elif cornerBuffer[1]=='D':
                if cornerBuffer[2]=='R':
                    index = [8,2,6]
                elif cornerBuffer[2]=='L':
                    index = [6,0,8]
            elif cornerBuffer[1]=='L':
                if cornerBuffer[2]=='U':
                    index = [0,2,6]
                elif cornerBuffer[2]=='D':
                    index = [6,8,0]
        elif cornerBuffer[0]=='R':
            if cornerBuffer[1]=='U':
                if cornerBuffer[2]=='F':
                    index = [0,8,2]
                elif cornerBuffer[2]=='B':
                    index = [2,2,0]
            elif cornerBuffer[1]=='F':
                if cornerBuffer[2]=='U':
                    index = [0,2,8]
                elif cornerBuffer[2]=='D':
                    index = [6,8,2]
            elif cornerBuffer[1]=='D':
                if cornerBuffer[2]=='F':
                    index = [6,2,8]
                elif cornerBuffer[2]=='B':
                    index = [8,8,6]
            elif cornerBuffer[1]=='B':
                if cornerBuffer[2]=='U':
                    index = [2,0,2]
                elif cornerBuffer[2]=='D':
                    index = [8,6,8]
        elif cornerBuffer[0]=='D':
            if cornerBuffer[1]=='F':
                if cornerBuffer[2]=='R':
                    index = [2,8,6]
                elif cornerBuffer[2]=='L':
                    index = [0,6,8]
            elif cornerBuffer[1]=='R':
                if cornerBuffer[2]=='F':
                    index = [2,6,8]
                elif cornerBuffer[2]=='B':
                    index = [8,8,6]
            elif cornerBuffer[1]=='B':
                if cornerBuffer[2]=='R':
                    index = [8,6,8]
                elif cornerBuffer[2]=='L':
                    index = [6,8,6]
            elif cornerBuffer[1]=='L':
                if cornerBuffer[2]=='F':
                    index = [0,8,6]
                elif cornerBuffer[2]=='B':
                    index = [6,6,8]
        elif cornerBuffer[0]=='B':
            if cornerBuffer[1]=='U':
                if cornerBuffer[2]=='R':
                    index = [0,2,2]
                elif cornerBuffer[2]=='L':
                    index = [2,0,0]
            elif cornerBuffer[1]=='R':
                if cornerBuffer[2]=='U':
                    index = [0,2,2]
                elif cornerBuffer[2]=='D':
                    index = [6,8,8]
            elif cornerBuffer[1]=='D':
                if cornerBuffer[2]=='R':
                    index = [6,8,8]
                elif cornerBuffer[2]=='L':
                    index = [8,6,6]
            elif cornerBuffer[1]=='L':
                if cornerBuffer[2]=='U':
                    index = [2,0,0]
                elif cornerBuffer[2]=='D':
                    index = [8,6,6]
        elif cornerBuffer[0]=='L':
            if cornerBuffer[1]=='U':
                if cornerBuffer[2]=='F':
                    index = [2,6,0]
                elif cornerBuffer[2]=='B':
                    index = [0,0,2]
            elif cornerBuffer[1]=='F':
                if cornerBuffer[2]=='U':
                    index = [2,0,6]
                elif cornerBuffer[2]=='D':
                    index = [8,6,0]
            elif cornerBuffer[1]=='D':
                if cornerBuffer[2]=='F':
                    index = [8,0,6]
                elif cornerBuffer[2]=='B':
                    index = [6,6,8]
            elif cornerBuffer[1]=='B':
                if cornerBuffer[2]=='U':
                    index = [0,2,0]
                elif cornerBuffer[2]=='D':
                    index = [6,8,6]
        return index
    
    
    def getCornerSequence(self):
        return cornerSequence
        
        
cubeCorners = Corner()